/* A program that helps rename mp3 files by processing their    */
/* filenames to meet ISO-9660.                                  */
/* Given a file or pipe of directory contents, this program     */
/* produces a list of MSDOS rename commands to fix those files. */

/* Author: Zach Tomaszewski */
/* Date:   01 May 2003      */

#include <iostream>
#include <fstream>
#include <string>

void usage();
string replaceall(string s, string search, string replace);

int main(int argc, char* argv[]) {
  string filename;
  string line;

  //get filename
  if (argc == 2) {
    filename = argv[1];
  }else if (argc == 1){
    cout << "Enter filename: ";
    cin >> filename;
  }else {
    usage();
    return(0);
  }

  //open file
  ifstream fileIn(filename.c_str());
  if (!fileIn){
    cout << "Could not open input file: " << filename << endl;
    return(1);
  }
  
  //process lines
  string oldname;
  string newname;
  int pos;
  while(!fileIn.eof()){
    getline(fileIn, line);
    if (line.find(".mp3", 0) != string::npos) { //work with files only
      line = replaceall(line, "\r", "");
      newname = oldname = line.substr(39);  //grab only filenames
      newname = replaceall(newname, ".mp3", ""); //drop ".mp3"
      newname = replaceall(newname, "'", "");    //drop "'"s
      newname = replaceall(newname, " & ", "-"); //turn " & " into -
      newname = replaceall(newname, "&", "-");   //turn "&" into -
      while(newname.length() > 26) { //remove full words to get length
        int space = newname.find_last_of(" ");
        int end = newname.length();
        newname.replace(space, end, "");
      }
      newname = replaceall(newname, " ", "_");  //turn " " into _
      newname += ".mp3";
      cout << "rename \"" << oldname << "\" " << newname << endl;
    }
  }

  return 0;
}


/*
 Prints a usage message to the screen
*/
void usage(){
  cout << "\nUsage: renamemp3 [filename]\n\n";
  cout << "\tIssues DOS rename commands for all mp3 files in ";
  cout << "the given file\n";
  cout << "\tso that files will meet ISO-9660 specs.\n";
  cout << endl;
}


/*
 Replaces all instances of "search" with "replace" found in s.
*/
string replaceall(string s, string search, string replace){
   int pos;
   for(pos = 0; 
      (pos = s.find(search)) != string::npos; 
      s.replace(pos, search.length(), replace)){ }
   return s;
}
